@@ -759,11 +759,8 @@ class Directory(BaseFSName,
         yield from os.walk(self.name, followlinks=followlinks)
     
     def walkback(self, followlinks=True):
-        """ Iterator over reverse-walked directories and files.
-            
-            N.B. Since I had to implement this myself, “followlinks”
-            doesn’t do anything yet. This is because I am lazy and
-            I lack intellectual rigor.
+        """ Iterator over reverse-walked directories and files. Use
+            the `followlinks=True` flag to do what you think it does.
             
             The return triple resembles that yielded by “os.walk(…)” –
             but unlike that function, modifying the directory listing
@@ -787,7 +784,7 @@ class Directory(BaseFSName,
                 yield directory, dirs, files
             if directory.name == ROOT_PATH:
                 break
-            directory = directory.parent()
+            directory = directory.parent(followlinks=followlinks)
     
     def flatten(self, destination, suffix=None, new_suffix=None):
         """ Copy the entire directory tree, all contents included, to a new
@@ -937,8 +934,9 @@ class Directory(BaseFSName,
             dirs[:] = list(filter(excluder, dirs))
             filenames = filter(excluder,
                         filter(searcher, files))
-            dotpaths.update(path_to_dotpath(os.path.join(root, filename),
-                                            relative_to=self.name)
+            dotpaths.update(path_to_dotpath(
+                            os.path.join(root, filename),
+                                         relative_to=self.name)
                             for filename in filenames)
         yield from sorted(dotpaths)
     
