@@ -35,12 +35,15 @@ from clu.all import import_clu_modules
 from clu.config.env import Environ
 from clu.constants import consts
 from clu.naming import nameof, qualified_import
-from clu.predicates import ispublic, listify
+from clu.predicates import ispublic, ismarkedprivate, listify
 from clu.repl import columnize
 
 # Set up the __all__ tuple:
 __all__ = list()
 
+# predicate for star-importing:
+ok_for_star_import = lambda name: ispublic(name) and not ismarkedprivate(name)
+
 # MODULE EXPORT FUNCTIONS: given a module name, export
 # either the module or its contents into a given namespace:
 def star_export(modulename, namespace, alltuple=__all__):
@@ -50,7 +53,7 @@ def star_export(modulename, namespace, alltuple=__all__):
     except ValueError:
         module = importlib.import_module(modulename)
     for name in dir(module):
-        if ispublic(name):
+        if ok_for_star_import(name):
             namespace[name] = getattr(module, name)
             alltuple += listify(name)
 
@@ -134,7 +137,6 @@ for mod in mods:
 # Additionals and corner-cases – imports requiring their own
 # bespoke import-statement forms:
 import collections.abc
-from PIL import Image
 from pprint import pprint, pformat
 
 pp = pprint
@@ -184,6 +186,7 @@ def explain(thing, width=None):
                   ljust=True))
 
 try:
+    from PIL import Image
     from instakit.utils.static import asset
 except (ImportError, SyntaxError, TypeError): # pragma: no cover
     pass
@@ -207,7 +210,7 @@ if 'user:script' in cluenv:
     if os.path.exists(user_script_path):
         user_script_globals = runpy.run_path(user_script_path)
         GLOBALS.update(user_script_globals)
-        __all__ += list(filter(ispublic, user_script_globals.keys()))
+        __all__ += list(filter(ok_for_star_import, user_script_globals.keys()))
     else:
         message = "CLU_USER_SCRIPT needs to point to a Python file"
         warnings.simplefilter('always')
